@@ -12,9 +12,6 @@
 #
 import os
 import sys
-#sys.path.insert(0, os.path.abspath('..'))
-#sys.path.insert(0, os.path.abspath('../pyqtgraph_examples'))
-#sys.path.insert(0, os.path.abspath('../src/temgymbasic'))
 sys.path.insert(0, os.path.abspath('../src'))
 
 # -- Project information -----------------------------------------------------
@@ -37,6 +34,21 @@ extensions = [
     'sphinx.ext.viewcode',
     'sphinx_licenseinfo']
 
+templates_path = ["_templates"]
+html_context = {
+    "sidebar_external_links_caption": "Links",
+    "sidebar_external_links": [
+        (
+            '<i class="fa fa-github fa-fw"></i> Source code',
+            "https://github.com/AMCLab/TemGymBasic",
+        ),
+        (
+            '<i class="fa fa-download fa-fw"></i> Zenodo',
+            "https://zenodo.org/communities/amcl/?page=1&size=20",
+        )
+    ],
+}
+
 # Add any paths that contain templates here, relative to this directory.
 templates_path = ['_templates']
 
@@ -58,6 +70,8 @@ master_doc = 'index'
 #
 html_theme = 'sphinx_rtd_theme'
 
+napoleon_numpy_docstring = True
+
 # on_rtd is whether we are on readthedocs.org
 on_rtd = os.environ.get('READTHEDOCS', None) == 'True'
 
